#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : app_run
# @Time         : 2019-08-30 13:51
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 
"""
通过在main文件
"""

from iapp import App


import os
os.sys.path.append("/Users/yuanjie/Desktop/Projects/Python/tql-App/examples/fds/models")

print(__import__('sklearn_lr_demo').feature_transform)



# app = App()
# app.add_route('/cmd', cmd)
# app.run()


